#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""EVH command to start or stop "proftpd" service.

This is the workaround to avoiding the "remount root error" caused by
"proftpd" which open "/etc/password" and "/etc/group".
"""

import ionas.request as request
import libevh.evhcmd as evhcmd
from pal_info import (PAL_SERVICECTRL_PATH,)
from product_conf.reqinfo import (Results, ReqTypes)

EVENTINFO_NAME = "eventinfo"
PREVIOUS_ATTR = "previous"

SERVICECTRL_REQ_XML = """<servicectrl>
    <servicelist>
        <service><name>proftpd</name></service>
    </servicelist>
</servicectrl>
"""


class EvhProftpdService(evhcmd.EvhCmd):
    """Event Handler to start or stop services for "disk" category."""

    def __send_request(self, target, type, body):
        """Send request entry to "target".""" 

        entry = request.Entry(type, body)
        return self.send_entry(entry, target)

    def __event_handler(self, entry):
        """Handle "event" request."""

        eventinfo = entry.get().get_node(EVENTINFO_NAME)
        if eventinfo.is_set_to_true(PREVIOUS_ATTR):
            self.__send_request(PAL_SERVICECTRL_PATH,
                                ReqTypes.SUSPEND,
                                SERVICECTRL_REQ_XML)
        else:
            self.__send_request(PAL_SERVICECTRL_PATH,
                                ReqTypes.RESUME,
                                SERVICECTRL_REQ_XML)

        entry.set_result(Results.OK)
        return entry

    def __init__(self, option=None):
        """Constructor."""

        evhcmd.EvhCmd.__init__(self, option=option)

        self.set_handler(ReqTypes.EVENT, self.__event_handler)

#
# Main
#

if __name__ == "__main__":
    EvhProftpdService(option=evhcmd.EvhCmdOption()).handle_request()
